/*
 * Copyright (c) 2014 Bruno Parmentier. This file is part of OpenBikeSharing.
 *
 * OpenBikeSharing is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * OpenBikeSharing is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenBikeSharing.  If not, see <http://www.gnu.org/licenses/>.
 */

package be.brunoparmentier.openbikesharing.app.ui;

import android.app.Activity;
import android.content.SharedPreferences;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import org.osmdroid.ResourceProxy;
import org.osmdroid.api.IMapController;
import org.osmdroid.tileprovider.tilesource.TileSourceFactory;
import org.osmdroid.util.GeoPoint;
import org.osmdroid.util.ResourceProxyImpl;
import org.osmdroid.views.MapView;
import org.osmdroid.views.overlay.ItemizedIconOverlay;
import org.osmdroid.views.overlay.ItemizedOverlay;
import org.osmdroid.views.overlay.OverlayItem;

import java.util.ArrayList;

import be.brunoparmentier.openbikesharing.app.R;
import be.brunoparmentier.openbikesharing.app.Station;

public class StationActivity extends Activity {
    private Station station;
    private MapView map;
    private IMapController mapController;
    private ItemizedOverlay<OverlayItem> stationLocationOverlay;
    private ResourceProxy mResourceProxy;
    SharedPreferences settings;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        settings = PreferenceManager.getDefaultSharedPreferences(this);
        mResourceProxy = new ResourceProxyImpl(getApplicationContext());

        setContentView(R.layout.activity_station);
        station = (Station) getIntent().getSerializableExtra("station");

        map = (MapView) findViewById(R.id.mapView);
        GeoPoint stationLocation = new GeoPoint((int) (station.getLatitude() * 1000000),
                (int) (station.getLongitude() * 1000000));

        Log.e(StationActivity.class.toString(), "lat: " + (int) (station.getLatitude() * 1000000));

        mapController = map.getController();
        mapController.setZoom(16);

        /* map tile source */
        String mapLayer = settings.getString("pref_map_layer", "");
        if (mapLayer.equals("mapnik")) {
            map.setTileSource(TileSourceFactory.MAPNIK);
        } else if (mapLayer.equals("cyclemap")) {
            map.setTileSource(TileSourceFactory.CYCLEMAP);
        } else if (mapLayer.equals("osmpublictransport")) {
            map.setTileSource(TileSourceFactory.PUBLIC_TRANSPORT);
        } else if (mapLayer.equals("mapquestosm")) {
            map.setTileSource(TileSourceFactory.MAPQUESTOSM);
        } else {
            map.setTileSource(TileSourceFactory.DEFAULT_TILE_SOURCE);
        }

        map.setMultiTouchControls(true);

        /* Station marker */
        final ArrayList<OverlayItem> items = new ArrayList<OverlayItem>();
        items.add(new OverlayItem("Title", "Description", stationLocation));
        Drawable newMarker = this.getResources().getDrawable(R.drawable.bike);
        this.stationLocationOverlay = new ItemizedIconOverlay<OverlayItem>(items, newMarker,
                new ItemizedIconOverlay.OnItemGestureListener<OverlayItem>() {

                    @Override
                    public boolean onItemSingleTapUp(int i, OverlayItem overlayItem) {

                        return false;
                    }

                    @Override
                    public boolean onItemLongPress(int i, OverlayItem overlayItem) {
                        return false;
                    }
                }, mResourceProxy);

        this.map.getOverlays().add(this.stationLocationOverlay);

        TextView stationName = (TextView) findViewById(R.id.stationName);
        TextView stationEmptySlots = (TextView) findViewById(R.id.stationEmptySlots);
        TextView stationFreeBikes = (TextView) findViewById(R.id.stationFreeBikes);

        stationName.setText(station.getName());
        stationEmptySlots.append(String.valueOf(station.getEmptySlots()));
        stationFreeBikes.append(String.valueOf(station.getFreeBikes()));

        mapController.animateTo(stationLocation);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.station, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        return super.onOptionsItemSelected(item);
    }
}
